@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="zh_CN">
 <context>
     <name>CanvasGridView</name>
     <message>
@@ -176,4 +178,4 @@
         <translation>试用期</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
