@@ -1,26 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2018 Deepin Technology Co., Ltd.
- *               2016 ~ 2018 dragondjf
- *
- * Author:     dragondjf<dingjiangfeng@deepin.com>
- *
- * Maintainer: dragondjf<dingjiangfeng@deepin.com>
- *             zccrs<zhangjide@deepin.com>
- *             Tangtong<tangtong@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "dgvfsfileinfo.h"
 #include "private/dgvfsfileinfo_p.h"
@@ -412,7 +392,7 @@ void DGvfsFileInfo::refreshCachesByStat()
         return;
     }
     d->cacheCanWrite  = access(d->fileInfo.absoluteFilePath().toStdString().c_str(), W_OK) == 0 ? 1 : 0;
-    d->cacheIsSymLink = S_ISLNK(statinfo.st_mode);
+    d->cacheIsSymLink = d->fileInfo.isSymLink();
     d->cacheFileSize = statinfo.st_size;
     d->inode = statinfo.st_ino;
     d->ownerid = static_cast<int>(statinfo.st_uid);
@@ -457,7 +437,7 @@ QIcon DGvfsFileInfo::fileIcon() const
     if (d->needThumbnail || d->hasThumbnail > 0) {
         d->needThumbnail = true;
 
-        const QIcon icon(DThumbnailProvider::instance()->thumbnailFilePath(d->fileInfo, DThumbnailProvider::Large));
+        const QIcon icon(DThumbnailProvider::instance()->thumbnailPixmap(d->fileInfo, DThumbnailProvider::Large));
 
         if (!icon.isNull()) {
             QPixmap pixmap = icon.pixmap(DThumbnailProvider::Large, DThumbnailProvider::Large);
