@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2021 Deepin Technology Co., Ltd.
-*
-* Author:     gongheng <gongheng@uniontech.com>
-*
-* Maintainer: zhengyouge <zhengyouge@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "pluginemblemmanagerprivate.h"
 #include "dfmextpluginmanager.h"
 #include "emblemicon/dfmextemblem.h"
@@ -130,8 +114,13 @@ void PluginEmblemManagerPrivate::run()
         data.first = "";
         data.second = -1;
         mutexQueue.lock();
-        while (filePathQueue.isEmpty())
+        while (filePathQueue.isEmpty()) {
+            if (!bWork) {
+                mutexQueue.unlock();
+                return;
+            }
             pathQueueNotEmpty.wait(&mutexQueue);
+        }
         data = filePathQueue.dequeue();
         mutexQueue.unlock();
         if (data.first == "" || data.second == -1)
@@ -162,13 +151,16 @@ void PluginEmblemManagerPrivate::run()
 void PluginEmblemManagerPrivate::startWork()
 {
     bWork = true;
-    if (!isRunning())
+    if (!isRunning()) {
         start();
+        DFMExtPluginManager::instance().monitorPlugins();
+    }
 }
 
 void PluginEmblemManagerPrivate::stopWork()
 {
     bWork = false;
+    pathQueueNotEmpty.wakeOne();
     wait();
 }
 
