@@ -1,4 +1,8 @@
-﻿#ifndef FILEMONITOR_H
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
+#ifndef FILEMONITOR_H
 #define FILEMONITOR_H
 
 
