@@ -1,30 +1,13 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     max-lv<lvwujun@uniontech.com>
- *
- * Maintainer: dengkeyun<dengkeyun@uniontech.com>
- *             xushitong<xushitong@uniontech.com>
- *             zhangsheng<zhangsheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "dfmglobal.h"
 #include "filebatchprocess.h"
 #include "dfmeventdispatcher.h"
 
+#include "controllers/filecontroller.h"
+
 #include <QDebug>
 #include <QByteArray>
 
@@ -208,8 +191,6 @@ QSharedMap<DUrl, DUrl> FileBatchProcess::customText(const QList<DUrl> &originUrl
     return result;
 }
 
-
-
 ////###: use the value of map to rename the file who name is the key of map.
 QMap<DUrl, DUrl> FileBatchProcess::batchProcessFile(const QSharedMap<DUrl, DUrl> &map)
 {
@@ -225,6 +206,7 @@ QMap<DUrl, DUrl> FileBatchProcess::batchProcessFile(const QSharedMap<DUrl, DUrl>
     // 实现批量回退
     DFMEventDispatcher::instance()->processEvent<DFMSaveOperatorEvent>();
 
+    bool checkHideRule = false;
     for (; beg != end; ++beg) {
         DUrl currentName{ beg.key() };
         DUrl hopedName{ beg.value() };
@@ -233,8 +215,14 @@ QMap<DUrl, DUrl> FileBatchProcess::batchProcessFile(const QSharedMap<DUrl, DUrl>
             continue;
         }
 
+        if(!checkHideRule) {
+            bool checkPass = FileController::doHiddenFileRemind(hopedName.fileName(), &checkHideRule);
+            if(!checkPass)
+                break;
+        }
+
        ///###: just cache files that rename successfully.
-       if (DFileService::instance()->renameFile(nullptr, currentName, hopedName) == true ) {
+       if (DFileService::instance()->renameFile(nullptr, currentName, hopedName, false, false) == true ) {
            cache[currentName] = hopedName;
        }
     }
