@@ -1,24 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     gongheng<gongheng@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             gongheng<gongheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "operatorcenter.h"
 #include "openssl-operator/pbkdf2.h"
@@ -232,7 +214,7 @@ bool OperatorCenter::createDirAndFile()
             configFile.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ReadGroup);
             configFile.close();
         } else {
-            qInfo() << "保险箱：创建配置文件失败！";
+            qWarning() << "Vault: create config file failed!";
         }
     }
 
@@ -385,7 +367,6 @@ bool OperatorCenter::checkPassword(const QString &password, QString &cipher)
         } else {
             cipher = strNewSaltAndCipher;
         }
-
     } else {   // 如果是旧版本，验证第一次加密的结果
         // 获得本地盐及密文
         QString strfilePath = makeVaultLocalPath(PASSWORD_FILE_NAME);
