@@ -1,25 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     yanghao<yanghao@uniontech.com>
- *
- * Maintainer: zhengyouge<zhengyouge@uniontech.com>
- *             yanghao<yanghao@uniontech.com>
- *             hujianzhong<hujianzhong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "filemanagerapp.h"
 #include "dfmglobal.h"
@@ -49,6 +30,7 @@
 #include "interfaces/dfileservices.h"
 #include "shutil/fileutils.h"
 #include "utils/utils.h"
+#include "utils/rlog/rlog.h"
 #include "app/filesignalmanager.h"
 
 #include "tag/tagmanager.h"
@@ -67,7 +49,7 @@ FileManagerApp::FileManagerApp(QObject *parent) : QObject(parent)
 {
     initApp();
     initView();
-    lazyRunInitServiceTask();
+    lazyRunTask();
     initSysPathWatcher();
     initConnect();
 }
@@ -157,6 +139,8 @@ void FileManagerApp::initApp()
     /*init emblemplugin manager*/
     DFMGlobal::initEmblemPluginManagerConnection();
 
+    DFMGlobal::initRlogManager();
+
     QThreadPool::globalInstance()->setMaxThreadCount(MAX_THREAD_COUNT);
 }
 
@@ -176,9 +160,16 @@ void FileManagerApp::initTranslation()
 
 }
 
-void FileManagerApp::lazyRunInitServiceTask()
+void FileManagerApp::lazyRunTask()
 {
     QTimer::singleShot(1500, initService);
+
+    // report app startup event
+    QTimer::singleShot(500, this, [=](){
+        QVariantMap data;
+        data.insert("type", true);
+        rlog->commit("AppStartup", data);
+    });
 }
 
 void FileManagerApp::initSysPathWatcher()
