@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     xinglinkun<xinglinkun@uniontech.com>
- *
- * Maintainer: xinglinkun<xinglinkun@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include <gtest/gtest.h>
 #include <gmock/gmock-matchers.h>
 #include <QTest>
@@ -65,3 +49,15 @@ TEST_F(ButtonTest, key_pressevent_of_space)
     m_button->keyPressEvent(&event);
     EXPECT_TRUE(bjudge);
 }
+
+TEST_F(ButtonTest, mouse_pressevent_of_editLabel)
+{
+//    bool bjudge = false;
+//    QObject::connect(m_eidtLabel, &EditLabel::editLabelClicked, m_button, [&]{
+//        bjudge = true;
+//    });
+//    QMouseEvent event(QEvent::User, QPoint(), Qt::LeftButton, Qt::LeftButton, Qt::KeyboardModifiers());
+//    m_eidtLabel->mousePressEvent(&event);
+//    EXPECT_TRUE(bjudge);
+}
+
