@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     zhangyu<zhangyub@uniontech.com>
- *
- * Maintainer: zhangyu<zhangyub@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include <gtest/gtest.h>
 #include <gmock/gmock-matchers.h>
@@ -110,8 +93,8 @@ TEST(ScreenObject, geometry)
     ScreenManagerWayland smw;
     auto myScreens = smw.logicScreens();
     ASSERT_EQ(screenList.size(),myScreens.size());
-
-    for (int i = 0; i < myScreens.size(); ++i){
+    int srcrenCount = myScreens.size();
+    for (int i = 0; i < srcrenCount; ++i){
         ScreenPointer obj = myScreens[i];
         ScreenPointer sc = screenList[i];
         if (!sc->name().isEmpty()) {
