@@ -1,24 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     liqiang<liqianga@uniontech.com>
- *
- * Maintainer: liqiang<liqianga@uniontech.com>
- *             zhangyu<zhangyub@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include <gtest/gtest.h>
 #include <gmock/gmock-matchers.h>
@@ -35,7 +17,7 @@
 
 TEST(DCustomActionBuilder, set_active_dir_empty)
 {
-    DCustomActionBuilder builder;
+    DCustomActionBuilder builder(nullptr);
     DUrl url("");
     builder.setActiveDir(url);
     EXPECT_EQ(builder.m_dirName, "");
