@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include <gtest/gtest.h>
 #include <gmock/gmock-matchers.h>
 
@@ -16,6 +20,7 @@
 #define protected public
 #include "views/dfiledialog.h"
 #include "views/dfilemanagerwindow_p.h"
+#include "views/computerview.h"
 
 
 namespace  {
@@ -388,7 +393,14 @@ TEST_F(TestDFileDialog, tst_fmEventFilter)
 TEST_F(TestDFileDialog, tst_handleNewView)
 {
     DFileView view;
+    ComputerView cpView;
+
+    m_fileDialog->handleNewView(&cpView);
+    EXPECT_EQ(m_fileDialog->d_ptr->view, nullptr);
+
     m_fileDialog->handleNewView(&view);
+    EXPECT_EQ(m_fileDialog->d_ptr->view, &view);
+
     view.setRootUrl(DUrl("/home"));
     view.selectAll();
     QEventLoop loop;
@@ -451,4 +463,3 @@ TEST_F(TestDFileDialog, tst_adjustPostion)
 
     EXPECT_NE(pt0, pt1);
 }
-
